searchData={"items":[{"type":"module","title":"PhoenixTypedForm","doc":"A macro that enforces a typed schema for your Phoenix LiveView forms.\nThe idea is that you define your schema and an optional changeset, then let the macro do the heavy lifting from there.\n\nThe macro provides a way to create a new form, update a form, and check if a form is valid for submission, all based on your schema and changeset.\n\nA typed form will have the following properties:\n- All form fields are required\n- All form fields are nillable - The user can delete a field and it should be fine to render, but not fine to submit\n- Is validate-able - All fields are required to be filled out before a form is considered valid\n\nThe macro suports:\n- Default values across all forms - Allows you to specify default form options via @default_values in the form of attrs.\n- Default values on new form creation - Allows you to override or specify a different default when creating a form - useful\n  for when your form requires something you don't have at compile time, like pulling in the policy quantity for a claim.\n- Custom changesets & Runtime changeset contraints - Allows you to specify constraints on the form at runtime,\n  like a max_qty for a claim form\n\n# Example\n\nHere's an example of how to use this module in your Phoenix app. Let's say you want a really simple form for a user to\nenter a quantity for a purchase order. You'd define a module like this for your form:\n\n```elixir\ndefmodule BasicForm do\n  use PhoenixTypedForm\n\n  # Define the schema for the form\n  typed_schema do\n    field :qty, :integer\n  end\n\n  # Bring in the form helpers\n  def_typed_form()\n\n  # And finally render the form to the user\n  def render_form(assigns) do\n    # phx-submit also works instead of phx-change\n    <.form for={@form} phx-change=\"update-form\">\n       Enter qty \n      <.input\n        field={@form[:qty]}\n        type=\"number\"\n        step=\"1.0\"\n        label=\"Qty\"\n        min=\"0\"\n        # This will show the last value that's been validated by the changeset\n        # You can also use `value={@form.params.qty}` to show the last value that's been submitted\n        value={@form.data.qty}\n        class={@class}\n        errors={get_error(@form, :qty)}\n        required\n      />\n    </.form>\n  end\nend\n```\n\nAnd then in your LiveView, all you have to do is\n1) create a new form and put it in your socket assigns\n2) handle the event fired by the form\n\nIf the new details are invalid, the form can render the changeset error straight to the user, giving them feedback as early as possible.\nThis macro could also be applied to forms in a controller, but it was intended to be used with LiveView.\n\n```elixir\ndefmodule YourLiveView do\n  use Phoenix.LiveView\n\n  def mount(_params, _session, socket) do\n    {:ok, assign(socket, form: BasicForm.new_form())}\n  end\n\n  def handle_event(\"update-form\", %{\"form\" => form_params}, socket) do\n    {:noreply, assign(socket, form: BasicForm.update_form(form_params))}\n  end\nend\n```\n\nTo add a form in your heex template, it's really simple. Just invoke the render_form function component:\n\n```elixir\n<%= BasicForm.render_form form={@form} %>\n```","ref":"PhoenixTypedForm.html"},{"type":"macro","title":"PhoenixTypedForm.def_typed_form/1","doc":"","ref":"PhoenixTypedForm.html#def_typed_form/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}